# -*- coding: utf-8 -*-
from setuphelpers import *

uninstallkey = []

service_name = 'Netlogon'
service_start_mode = 'Automatic'


def install():
    print("Actual status of %s is: %s" % (service_name,service_get_start_mode(service_name)))
    if not service_get_start_mode(service_name) == 'Auto':
        service_set_start_mode(service_name, service_start_mode)
        service_restart(service_name)
        print("New status of %s is: %s" % (service_name,service_get_start_mode(service_name)))


def update_package():
    # Incrementing version of the package
    control.version = '%s-%s'%(control.get_software_version(),int(control.version.split('-')[-1])+1)
    control.save_control_to_wapt()
    print('Changing version to: %s in WAPT\\control' % control.version)


def audit():
    if not service_installed(service_name):
        print("Service %s is NOT installed, you will probably need to repair Windows" % service_name)
        return "ERROR"
    if not service_get_start_mode(service_name) == 'Auto':
        print("Starting mode of %s is NOT: %s. WAPT is reinstalling the package to fix that" % (service_name,service_start_mode))
        install()
    if not service_is_running(service_name):
        print("Service %s was NOT running. WAPT is restarting it" % service_name)
        service_restart(service_name)
        install()
        return "WARNING"
    else:
        print("Service %s is running" % service_name)
        return "OK"




def service_set_start_mode(service_name, StartMode):
    """Changing start mode of a service
    Usable values: "Boot" "System" "Automatic" "Manual" "Disabled"
    Informations: https://msdn.microsoft.com/en-us/library/aa384896(v=vs.85).aspx
    """
    import wmi
    c = wmi.WMI()
    for service in c.Win32_Service(Name=service_name):
        service.ChangeStartMode(StartMode=StartMode)


def service_get_start_mode(service_name):
    """Getting actual start mode of a service
    Returned values: "Boot" "System" "Auto" "Manual" "Disabled"
    """
    import wmi
    s = wmi.WMI()
    for service in s.Win32_Service(Name=service_name):
        #print(service.State, service.StartMode, service.Name, service.DisplayName)
        return service.StartMode



